﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Agilent ESA/PSA Take Sweep Only
INSTRUMENT:            Sub Agilent ESA/PSA Take Sweep (MKF)
INSTRUMENT:            Sub Agilent ESA/PSA Take Sweep (MKCF)
INSTRUMENT:            Sub Agilent ESA/PSA Take Sweep (MKPK)
INSTRUMENT:            Sub Agilent ESA/PSA Take Sweep (MKPK, MKCF)
DATE:                  2011-10-31
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       96
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Agilent ESA/PSA series
#
#  Compatibility:
#        MET/CAL 7.2 or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  Functional Descriptions:
#
#  Sub Agilent ESA/PSA Take Sweep Only:
#  This sub takes two sweeps and does not alter the marker, center frequency,
#  or any other UUT settings.
#
#  Sub Agilent ESA/PSA Take Sweep (MKF):
#  This sub takes two sweeps, placing the active marker at a frequency passed
#  by the calling procedure after the second sweep. Note that the active
#  marker may be the "delta" marker, if previously specified in the calling
#  procedure.
#
#  Sub Agilent ESA/PSA Take Sweep (MKCF):
#  This sub takes two sweeps, placing the active marker at center frequency
#  on the display after each sweep. Note that the active marker may be the
#  "delta" marker, if previously specified in the calling procedure.
#
#  Sub Agilent ESA/PSA Take Sweep (MKPK, MKCF):
#  This sub takes two sweeps, placing the active marker at the highest peak
#  present on the display after each sweep, moving the marker to the UUT
#  center frequency upon completion. Note that the active marker may be the
#  "delta" marker, if specified previously in the calling procedure.
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Set number of sweeps.
  1.001  MATH         Sweeps = 2

  1.002  WHILE        Sweeps > 0
  1.003  SCPI         [T75000]INIT:IMM

# Mode: Marker to Frequency.
  1.004  IF           PSUBI("(MKF)")
# Set UUT marker to specified frequency in Hertz.
  1.005  SCPI         CALC:MARK:X [V @MarkerFreq]

# Mode: Marker to Center Frequency.
  1.006  ELSEIF       PSUBI("(MKCF)")
# Set UUT marker to center frequency.
  1.007  SCPI         CALC:MARK:CENT

# Mode: Marker to Peak.
  1.008  ELSEIF       PSUBI("(MKPK)")
# Set UUT marker to (highest) peak.
  1.009  SCPI         CALC:MARK:MAX

# Mode: Marker to Peak, (Peak) Marker to Center Frequency.
  1.010  ELSEIF       PSUBI("(MKPK, MKCF)")
# Set UUT marker to (highest) peak; move marker to center frequency.
  1.011  SCPI         CALC:MARK:MAX
  1.012  SCPI         CALC:MARK:CENTER
  1.013  ENDIF

  1.014  MATH         Sweeps = Sweeps - 1
  1.015  ENDW

  1.016  END
