﻿Copyright (c) (2014) Fluke Corporation.                  All rights reserved.
=============================================================================
INSTRUMENT:            Sub PSA Set Ref Level (Log) /9640
INSTRUMENT:            Sub PSA Set Ref Level (Lin) /9640
DATE:                  2014-11-10 11:43:45
AUTHOR:                Fluke
REVISION:              $Revision: 9722 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       178
CONFIGURATION:         Fluke 9640A
CONFIGURATION:         Fluke 9640A-50
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        HP/Agilent PSA series
#
#  Compatibility:
#        MET/CAL 7.2 or later
#
#  Subprocedures:
#        Sub Agilent ESA/PSA Take Sweep (MKPK)
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The parameters for this procedure are passed from the calling procedures.
#  Except for those identified as "Optional", all parameters are required.
#
#  @CenterFreq : The 9640A output frequency.
#  @PSA_RefLvl : The desired reference level as measured by the UUT (PSA).
#  @TestLvl    : The 9640A output level required to generate the specified
#                reference level.
#  @HiLimit    : The upper limit of the setting aperture (in dBm).
#  @LoLimit    : The lower limit of the setting aperture (in dBm).
#
#  Example(1):
# 1.001  MATH         @TestName = "Input Attenuation Switching"
# 1.002  MATH         @PSA_RefLvl = -55; @TestLvl = @PSA_RefLvl
# 1.003  MATH         @9640Freq = 50E+6; @9640RefOut = 10E+6
# 1.004  MATH         @HiLimit = @PSA_RefLvl + 0.02
# 1.005  MATH         @LoLimit = @PSA_RefLvl - 0.02
# 1.006  SCPI         CALC:MARK:Y?[I]
#
# 1.007  WHILE        ((MEM <= @LoLimit) || (MEM >= @HiLimit)) && NOT(@Error)
# 1.008  CALL         Sub PSA Set Ref Level (Log) /9640
# 1.009  ENDW
#
# 1.010  IF           @Error
# 1.011  EVAL   -e 0 : An error occurred during the [V @TestName].
# 2.001  MATH         @Error = 0
# 2.002  END
# 2.003  ENDIF
#
#  Example(2):
# 1.001  MATH         @TestName = "Input Attenuation Switching"
# 1.002  MATH         @PSA_RefLvl = 223.6E-3; @9640Lvl    = @PSA_RefLvl
# 1.003  MATH         @9640Freq   = 50E+6;    @9640RefOut = 10E+6
# 1.004  MATH         @HiLimit    = @PSA_RefLvl + 4E-3
# 1.005  MATH         @LoLimit    = @PSA_RefLvl - 4E-3
#
# 1.006  WHILE        ((MEM <= @LoLimit) || (MEM >= @HiLimit)) && NOT(@Error)
# 1.007  HEAD         -2 Setting UUT reference level, Please Wait...
# 1.008  CALL         Sub PSA Set Ref Level (Lin) /9640
# 1.009  ENDW
#
# 1.010  IF           @Error
# 1.011  EVAL   -e 0 : An error occurred during [V @TestName] test.
# 2.001  MATH         @Error = 0
# 2.002  END
# 2.003  ENDIF
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  WHILE        ((MEM <= @LoLimit) || (MEM >= @HiLimit))
  1.002  MATH         Delta = (@PSA_RefLvl - MEM)
  1.003  MATH         @9640Lvl = @9640Lvl + Delta

  1.004  IF           PSUBI("Log")

  1.005  IF           (@9640Lvl < -130) || (@9640Lvl > +24)
  1.006  OPBR         -z Error: Unable to adjust [V @9640DevName] output
  1.006  OPBR         [32]      level within its operating range to achieve
  1.006  OPBR         [32]      the desired test level ([V @PSA_RefLvl] dBm).
  1.006  OPBR
  1.006  OPBR         [32]      Verify UUT test requirements and connections
  1.006  OPBR         [32]      prior to retrying, if desired.
  1.006  OPBR
  1.006  OPBR         Do you wish to RETRY?
  1.006  OPBR
  1.006  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.006  OPBR         to be terminated.)

  1.007  IF           MEM1
# Restart this loop with the original TestLvl.
  1.008  MATH         @9640Lvl = @PSA_RefLvl
  1.009  ELSE
  1.010  MATH         @Error = 1
  1.011  END
  1.012  ENDIF

  1.013  ENDIF

# Select 9640A FSC depending on existence of variables that 'control' the
# 9640A REF FREQUENCY OUTPUT and REF FREQUENCY IN pased from the calling
# procedure.

  1.014  IF           NOT(ISVAR("@9640RefOut")) && ISVAR("@9640RefIn")
  1.015  9640         TimebaseAccuracyOff
  1.015  9640         OutputImp = 50 Ohms; ExtRefFreq = [V @9640RefIn] Hz
  1.015  9640         +Level = [V @9640Lvl] dBm; Freq = [V @9640Freq] Hz
  1.016  ELSEIF       ISVAR("@9640RefOut") && NOT(ISVAR("@9640RefIn"))
  1.017  9640         OutputImp = 50 Ohms; RefFreqOutp = [V @9640RefOut] Hz
  1.017  9640         +Level = [V @9640Lvl] dBm; Freq = [V @9640Freq] Hz
  1.018  ELSEIF       ISVAR("@9640RefOut") && ISVAR("@9640RefIn")
  1.019  9640         ExtRefFreq = [V @9640RefIn] Hz; TimebaseAccuracyOff
  1.019  9640         RefFreqOutp = [V @9640RefOut] Hz; OutputImp = 50 Ohms
  1.019  9640         +Level = [V @9640Lvl] dBm; Freq = [V @9640Freq] Hz
  1.020  ELSE
  1.021  9640         OutputImp = 50 Ohms
  1.021  9640         +Level = [V @9640Lvl] dBm; Freq = [V @9640Freq] Hz
  1.022  ENDIF

  1.023  ELSE

  1.024  IF           (@9640Lvl < 70.8E-9) || (@9640Lvl > 3.544)
  1.025  OPBR         -z Error: Unable to adjust [V @9640DevName] output
  1.025  OPBR         [32]      level within its operating range to achieve
  1.025  OPBR         [32]      the desired test level ([V @PSA_RefLvl] V).
  1.025  OPBR
  1.025  OPBR         [32]      Verify UUT test requirements and connections
  1.025  OPBR         [32]      prior to retrying, if desired.
  1.025  OPBR
  1.025  OPBR         Do you wish to RETRY?
  1.025  OPBR
  1.025  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.025  OPBR         to be terminated.)

  1.026  IF           MEM1
# Restart this loop with the original TestLvl.
  1.027  MATH         @9640Lvl = @PSA_RefLvl
  1.028  ELSE
  1.029  MATH         @Error = 1
  1.030  END
  1.031  ENDIF

  1.032  ENDIF

  1.033  IF           NOT(ISVAR("@9640RefOut")) && ISVAR("@9640RefIn")
  1.034  9640         TimebaseAccuracyOff
  1.034  9640         OutputImp = 50 Ohms; ExtRefFreq = [V @9640RefIn] Hz
  1.034  9640         +Level = [V @9640Lvl] V; Freq = [V @9640Freq] Hz
  1.035  ELSEIF       ISVAR("@9640RefOut") && NOT(ISVAR("@9640RefIn"))
  1.036  9640         OutputImp = 50 Ohms; RefFreqOutp = [V @9640RefOut] Hz
  1.036  9640         +Level = [V @9640Lvl] V; Freq = [V @9640Freq] Hz
  1.037  ELSEIF       ISVAR("@9640RefOut") && ISVAR("@9640RefIn")
  1.038  9640         ExtRefFreq = [V @9640RefIn] Hz; TimebaseAccuracyOff
  1.038  9640         RefFreqOutp = [V @9640RefOut] Hz; OutputImp = 50 Ohms
  1.038  9640         +Level = [V @9640Lvl] V; Freq = [V @9640Freq] Hz
  1.039  ELSE
  1.040  9640         OutputImp = 50 Ohms
  1.040  9640         +Level = [V @9640Lvl] V; Freq = [V @9640Freq] Hz
  1.041  ENDIF

  1.042  ENDIF

  1.043  SCPI         INIT:IMM;*WAI;:CALC:MARK:MAX;Y?[I]
  1.044  ENDW

  1.045  END
